summaryrefslogtreecommitdiff
path: root/lib/scripts/hotkeys.js
diff options
context:
space:
mode:
Diffstat (limited to 'lib/scripts/hotkeys.js')
-rw-r--r--lib/scripts/hotkeys.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/scripts/hotkeys.js b/lib/scripts/hotkeys.js
index bff28530d..76a277aea 100644
--- a/lib/scripts/hotkeys.js
+++ b/lib/scripts/hotkeys.js
@@ -26,7 +26,7 @@ function Hotkeys() {
* Initialization
*
* This function looks up all the accesskeys used in the current page
* (at anchor elements and input elements [type="submit"]) and registers
* appropriate shortcuts.
*
* Secondly, initialization registers listeners on document to catch all
@@ -59,10 +59,10 @@ function Hotkeys() {
});
/**
* Lookup all input [type="submit"] with accesskey and register event -
* perform "click" on a button.
*/
- var inputs = document.getElementsByTagName("input");
+ var inputs = document.getElementsByTagName("button");
t.each(inputs, function(i) {
if (i.type == "submit" && i.accessKey != "") {
t.addShortcut(t.modifier + '+' + i.accessKey, function() {
@@ -26,7 +26,7 @@ function Hotkeys() {
*
* This function looks up all the accesskeys used in the current page
- * (at anchor elements and input elements [type="submit"]) and registers
+ * (at anchor elements and button elements [type="submit"]) and registers
* appropriate shortcuts.
*
@@ -59,10 +59,10 @@ function Hotkeys() {
});
/**
- * Lookup all input [type="submit"] with accesskey and register event -
+ * Lookup all button [type="submit"] with accesskey and register event -
* perform "click" on a button.
*/